/*
 * Copyright 1995 Steve Passe
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of AUTHOR (Steve Passe)
 * is not be used in advertising or publicity pertaining to distribution of
 * the software without specific, written prior permission.  AUTHOR makes no
 * representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL AUTHOR
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * AUTHOR:     Steve Passe <smp@csn.net>
 */


/* rcsid = "$Id: vm100.h,v 1.3 1995/08/27 05:08:59 smp Exp smp $" */

#ifndef VM100_H
#define VM100_H

#if COMMENT

wire the vm100 as follows:

tty pin		vm100 pin

 2		 2
 3		 3
 4		 4
 7		 7
 8		 5	<- NOTE: vm100 CTS wired to tty DCD
20		20

#endif /* COMMENT */


#define OK 			(0)
#define BAD			(-1)


/******************************************************************************
 * public interface to vm100
 *****************************************************************************/

/*
 * start a vm100 handler daemon (ie, process)
 *
 *  if ringStartCallback is not NULL, arrange for it to catch SIGUSR1
 *  if ringStopCallback is not NULL, arrange for it to catch SIGUSR2
 *
 * returns the pid of the daemon process to the caller (parent)
 */
int	vm100Daemon( char* port,
		     void (*ringStartCallback)(),
		     void (*ringStopCallback)() );

/*
 * cause the vm100 daemon to go off-hook
 */
int	vm100OffHook( int daemon );

/*
 * cause the vm100 daemon to go on-hook
 */
int	vm100OnHook( int daemon );


/*
 * Note: this is a user provided function!
 * handle a vm100 generated 'start of ring' signal
 *
 *  if used, it's address is passed to vm100Daemon(), see above
 *
 * void ringStartCallback(void);
 */


/*
 * Note: this is a user provided function!
 * handle a vm100 generated 'end of ring' signal
 *
 *  if used, it's address is passed to vm100Daemon(), see above
 *
 * void ringStopCallback(void);
 */

#endif VM100_H
