/*
 * Copyright 1995 Steve Passe
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of AUTHOR (Steve Passe)
 * is not be used in advertising or publicity pertaining to distribution of
 * the software without specific, written prior permission.  AUTHOR makes no
 * representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL AUTHOR
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * AUTHOR:     Steve Passe <smp@csn.net>
 */


static char* rcsid = "$Id: vmtest.c,v 1.1 1995/08/27 05:08:58 smp Exp smp $";

#include <stdio.h>
#include <errno.h>
#include <signal.h>
#include <sys/types.h>

#include "vm100.h"

#define VM100_PORT		"/dev/ttyd1"
#define PHONE_LOG		"/usr/local/control/log/phonelog"

#define TRUE			(1)
#define	FALSE			(0)


int	vm100;
int	ringReport = FALSE;
int	backGround = FALSE;

FILE*	phoneLog = NULL;

void	byeBye( void );
void	ringStart( void );
void	ringStop( void );
int	reportTime( FILE* fp, char* s1, char* s2 );


/*
 * 
 */
int
main( int argc, char* argv[] )
{
    struct sigaction action;
    char string[80];
    int status;

    if ( (phoneLog = fopen( PHONE_LOG, "a" )) == NULL )
    {
	perror( "phone log open()" );
	exit( 1 );
    }
    reportTime( phoneLog, "\n\nVM-100 monitor started on ", "\n" );

    /* CHEAP argc processing */
    if ( (argc > 1) && (argv[1][0] == '-') && (argv[1][1] == 'b') )
    {
	backGround = TRUE;
    }

    /*  */
    action.sa_handler = byeBye;
    if ( sigaction( SIGTERM, &action, NULL ) < 0 )
    {
	perror( "sigaction" );
	exit( 1 );
    }

    /* a child process will be spawned, it's pid returned in vm100 */
    if ( (vm100 = vm100Daemon( VM100_PORT, ringStart, ringStop )) == BAD )
    {
	perror( "daemonize" );
	exit( 1 );
    }

    if ( backGround )
    {
	close( 0 );
	close( 1 );
	close( 2 );

	wait( &status );

	reportTime( phoneLog, "\nVM-100 monitor stopped on ", "\n" );
	exit( 0 );
    }
    else
    {
	for ( ; /* ever */; )
	{
	    fgets( string, 79, stdin );
	    switch ( string[0] )
	    {

	    case 'f':
		vm100OffHook( vm100 );
		break;

	    case 'n':
		vm100OnHook( vm100 );
		break;

	    case 'q':
		byeBye();

	    default:
		break;

	    }
	}
    }
}


/*
 * 
 */
void
byeBye( void )
{
    int status;

    kill( vm100, SIGTERM );
    wait( &status );

    reportTime( phoneLog, "\nVM-100 monitor stopped on ", "\n" );
    exit( 0 );
}


/*
 * notice the start of a ring 'cycle' via SIGUSR1
 */
void
ringStart( void )
{
    if ( ringReport == FALSE )
    {
	fputs( "Ringy", phoneLog );
	ringReport = TRUE;
    }
    else
    {
	fputs( "\nERROR: last Ringy had no Dingy!\n", phoneLog );
    }

    fflush( phoneLog );
}


/*
 * notice the end of a ring 'cycle' via SIGUSR2
 */
void
ringStop( void )
{
    if ( ringReport == TRUE )
    {
	fputs( " Dingy\n", phoneLog );
	reportTime( phoneLog, "The phone rang on ", "\n" );
	ringReport = FALSE;
    }
    else
    {
	fputs( "\nERROR: this Dingy had no Ringy!\n", phoneLog );
    }

    fflush( phoneLog );
}


/*
 * 
 */
int
reportTime( FILE* fp, char* s1, char* s2 )
{
    time_t tloc;

    time( &tloc );
    fprintf( fp, "%s%s%s", s1, ctime( &tloc ), s2 );
    fflush( fp );
}
